@@ -1,5 +1,5 @@
 /* mechinfo.c --- Definition of EXTERNAL mechanism.
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+ * Copyright (C) 2002-2012 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,8 +20,8 @@
  *
  */
 
-#if HAVE_CONFIG_H
-# include "config.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
 #endif
 
 /* Get specification. */
