@@ -1,5 +1,5 @@
 /* mechinfo.c --- Definition of GS2 mechanism.
- * Copyright (C) 2006, 2010 Simon Josefsson
+ * Copyright (C) 2006-2012 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -21,7 +21,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-# include "config.h"
+#include "config.h"
 #endif
 
 /* Get specification. */
@@ -30,45 +30,44 @@
 Gsasl_mechanism gsasl_gs2_krb5_mechanism = {
   GSASL_GS2_KRB5_NAME,
   {
-    NULL,
-    NULL,
+   NULL,
+   NULL,
 #ifdef USE_CLIENT
-    _gsasl_gs2_client_start,
+   _gsasl_gs2_client_start,
 #else
-    NULL,
+   NULL,
 #endif
 #ifdef USE_CLIENT
-    _gsasl_gs2_client_step,
+   _gsasl_gs2_client_step,
 #else
-    NULL,
+   NULL,
 #endif
 #ifdef USE_CLIENT
-    _gsasl_gs2_client_finish,
+   _gsasl_gs2_client_finish,
 #else
-    NULL,
+   NULL,
 #endif
-    NULL,
-    NULL
-  },
+   NULL,
+   NULL}
+  ,
   {
-    NULL,
-    NULL,
+   NULL,
+   NULL,
 #ifdef USE_SERVER
-    _gsasl_gs2_server_start,
+   _gsasl_gs2_server_start,
 #else
-    NULL,
+   NULL,
 #endif
 #ifdef USE_SERVER
-    _gsasl_gs2_server_step,
+   _gsasl_gs2_server_step,
 #else
-    NULL,
+   NULL,
 #endif
 #ifdef USE_SERVER
-    _gsasl_gs2_server_finish,
+   _gsasl_gs2_server_finish,
 #else
-    NULL,
+   NULL,
 #endif
-    NULL,
-    NULL
-  }
+   NULL,
+   NULL}
 };
